@@ -16,7 +16,7 @@ class MockSynapse(Synapse):
         self.logger.info(request)
         print()
 
-    def connect(self):
+    def test(self):
         return self.connection
 
     def synapse_info(self):
@@ -75,7 +75,7 @@ class MockSynapse(Synapse):
         return event_datas
 
 def test_connect():
-    synapse_request = Request(type=RequestType.CONNECT,
+    synapse_request = Request(type=RequestType.TEST,
         connection=get_connection(),
         body=None).json()
     synapse = MockSynapse(synapse_request)
