@@ -16,7 +16,7 @@ class MockResponseValidationSynapse(Synapse):
         self.logger.info(request)
         print()
 
-    def connect(self):
+    def test(self):
         connections = []
         connections.append(self.connection)
         return connections
@@ -65,12 +65,12 @@ def _execute(synapse_request):
     return err_resp
 
 def test_connect():
-    synapse_request = Request(type=RequestType.CONNECT,
+    synapse_request = Request(type=RequestType.TEST,
         connection=get_connection(),
         body=None).json()
     resp = _execute(synapse_request)
     assert isinstance(resp, ErrorResponse)
-    assert resp.message == 'Invalid response type for request RequestType.CONNECT'
+    assert resp.message == 'Invalid response type for request RequestType.TEST'
 
 
 def test_get_synapse_info():
